#ifndef __STAN__MATH__MATRIX__EIGEN_HPP__
#define __STAN__MATH__MATRIX__EIGEN_HPP__

#define EIGEN_DENSEBASE_PLUGIN "stan/math/matrix/EigenDenseBaseAddons.h"
#include <Eigen/Dense>
#include <Eigen/QR>

#endif
